@@ -1016,7 +1016,7 @@ def test_isnull():
     a = da.from_array(x, chunks=(2,))
     with ignoring(ImportError):
         assert_eq(da.isnull(a), np.isnan(x))
-        assert_eq(da.notnull(a), ~np.isnan(x))
+        assert_eq(da.notnull(a), ~(np.isnan(x)))
 
 
 def test_isnull_result_is_an_array():
