@@ -48,11 +48,11 @@ def test_read_text(fmt, bs, encoding):
         b = read_text(
             ".test.accounts.*.json", compression=fmt, blocksize=bs, encoding=encoding
         )
-        L, = compute(b)
+        (L,) = compute(b)
         assert "".join(L) == expected
 
         b = read_text(sorted(files), compression=fmt, blocksize=bs, encoding=encoding)
-        L, = compute(b)
+        (L,) = compute(b)
         assert "".join(L) == expected
 
         blocks = read_text(
