@@ -50,7 +50,7 @@ from ..highlevelgraph import HighLevelGraph
 # corresponding support in ``apply_concat_apply``. Specifically, this function
 # operates on matching partitions of frame-like objects passed as varargs.
 #
-# After the inital chunk step, the passed index is implicitly passed along to
+# After the initial chunk step, the passed index is implicitly passed along to
 # subsequent operations as the index of the parittions. Groupby operations on
 # the individual partitions can then access the index via the ``levels``
 # parameter of the ``groupby`` function. The correct argument is determined by
@@ -156,6 +156,8 @@ def _groupby_raise_unaligned(df, **kwargs):
         # since we're coming through apply, `by` will be a tuple.
         # Pandas treats tuples as a single key, and lists as multiple keys
         # We want multiple keys
+        if isinstance(by, str):
+            by = [by]
         kwargs.update(by=list(by))
     return df.groupby(**kwargs)
 
