@@ -1,9 +1,8 @@
-from __future__ import absolute_import, division, print_function
-
 import math
 import numbers
 import re
 import textwrap
+from collections.abc import Iterator, Mapping
 from distutils.version import LooseVersion
 
 import sys
@@ -24,7 +23,6 @@ from pandas.api.types import (
 
 from .extensions import make_array_nonempty, make_scalar
 from ..base import is_dask_collection
-from ..compatibility import PY2, Iterator, Mapping
 from ..core import get_deps
 from ..local import get_sync
 from ..utils import asciitable, is_arraylike, Dispatch, typename
@@ -464,6 +462,18 @@ def hash_object_pandas(
     )
 
 
+group_split_dispatch = Dispatch("group_split_dispatch")
+
+
+@group_split_dispatch.register((pd.DataFrame, pd.Series, pd.Index))
+def group_split_pandas(df, c, k):
+    indexer, locations = pd._libs.algos.groupsort_indexer(c, k)
+    df2 = df.take(indexer)
+    locations = locations.cumsum()
+    parts = [df2.iloc[a:b] for a, b in zip(locations[:-1], locations[1:])]
+    return dict(zip(range(k), parts))
+
+
 _simple_fake_mapping = {
     "b": np.bool_(True),
     "V": np.void(b" "),
@@ -669,13 +679,6 @@ def index_summary(idx, name=None):
     return "{}: {} entries{}".format(name, n, summary)
 
 
-def series_type_like_df(df):
-    """Get the concrete series type compatible with df."""
-    # TODO: https://github.com/pandas-dev/pandas/issues/27824
-    # Use a standard API, which will handle empty DataFrames.
-    return type(df._meta.iloc[:, 0])
-
-
 ###############################################################
 # Testing
 ###############################################################
@@ -851,8 +854,7 @@ def assert_sane_keynames(ddf):
         assert isinstance(k, (str, bytes))
         assert len(k) < 100
         assert " " not in k
-        if not PY2:
-            assert k.split("-")[0].isidentifier()
+        assert k.split("-")[0].isidentifier()
 
 
 def assert_dask_dtypes(ddf, res, numeric_equal=True):
